Key |
--- | ---
q | Quit
r | Reload modified files
R | Reload snufflings
f | Toggle full screen mode
m | Toggle marker sidebar
c | Toggle main controls
: | Enter command
<space> | Forward one page in time
b | Backward one page in time
<pagedown> | Scroll tracks one page down
<pageup> | Scroll tracks one page up
+ | Show one track more
- | Show one track less
= | Show initial number of tracks
g | Go to selection / show all
G | Zoom to selection / zoom to trace visibility
n | Go to next marker
p | Go to previous marker
N | Go to next event marker
P | Go to previous event marker
<tab> | Go to next marker of active event
<shift> + <tab> | Go to previous marker of active event
a | Select all markers currently visible
A | Select all markers
d | Deselect all markers
0 ... 5 | Change color of marker
<f1> ... <f5> | Convert to phase marker
e | Convert to event marker / set active event / associate to event
E | Deactivate event
<f10> | Convert phase marker to normal marker
<backspace> | Delete marker
<up>, <down> | Set first motion polarity on selected marker
<shift> + <up>, <shift> + <down> | Unset first motion polarity on selected marker
<escape> | Abort picking
? | Help

Mouse |
--- | ---
Click and drag | Zoom and pan
Click and drag on time axis | Pan only
Click on marker | Select marker
<shift> + click on marker | Select additional marker
Wheel | Scroll tracks vertically
<ctrl> + wheel | Change number of tracks shown
Right-click | Menu
Double-click | Enter picking mode

Command |
--- | ---
`n|s|l|c [ <pattern> ]` | Reduce traces to those matching a given pattern. man
`hide <pattern> hide n|s|l|c <pattern>` | Hide traces whose network, station, location, and channel IDs match a given pattern. man
`unhide <pattern> unhide n|s|l|c <pattern>` | Unhide traces previously hidden with the hide command. man
`markers [0][1][2][3][4][5] markers all markers` | Toggle marker visibility. man
`scaling <vmin> <vmax> scaling <pattern> <vmin> <vmax> scaling` | Set scaling rules. man
`goto YYYY-MM[-DD[ HH[:MM[:SS[.XXX]]]]] goto HH:MM[:SS[.XXX]] goto <eventname>` | Jump to given time or event. man